@@ -37,6 +37,11 @@ class Window(BaseWindow):
             major_version=self.gl_version[0],
             minor_version=self.gl_version[1],
             forward_compatible=True,
+            red_size=8,
+            green_size=8,
+            blue_size=8,
+            alpha_size=8,
+            stencil_size=8,
             depth_size=24,
             double_buffer=True,
             sample_buffers=1 if self.samples > 1 else 0,
